#include "Sprite.h"
using namespace std;


CSprite::CSprite ()
{
	SaveLoad = new CSaveLoad;
	fullscreen = SaveLoad->LoadFullscreen();
}


CSprite::~CSprite ()
{
  // Surface freigeben
  SDL_FreeSurface (m_pImage);

} // Destruktor


// Load
//
// Aufgabe: Einfaches, nicht animiertes Sprite laden
//
void CSprite::Load (const string sFilename, const string sFilenameSca)
{
	if(fullscreen == true)
	{
		// Bitmap laden
		m_pImage = SDL_LoadBMP (sFilename.c_str () );
	}
	else
	{
		m_pImage = SDL_LoadBMP (sFilenameSca.c_str () );
	}

  // Rect initialisieren
  m_Rect.x = 0;
  m_Rect.y = 0;
			

  m_Rect.w = m_pImage->w;
  m_Rect.h = m_pImage->h;

} // Load


// Load
//
// Aufgabe: Animiertes Sprite laden
//
void CSprite::Load (const string sFilename, const string sFilenameSca, int NumFrames,
                    int FrameWidth, int FrameHeight)
{
  // Bitmap laden
  Load (sFilename, sFilenameSca);


  if(fullscreen)
  {
	// Rect fr Animationsphase initialisieren
	m_NumFrames   = NumFrames;
	m_FrameWidth  = FrameWidth;
	m_FrameHeight = FrameHeight;
	m_FrameRect.w = FrameWidth;
	m_FrameRect.h = FrameHeight;
	m_NumFramesX  = m_pImage->w / m_FrameWidth;
  }
  else
  {
	// Rect fr Animationsphase initialisieren
	m_NumFrames   = NumFrames;
	m_FrameWidth  = FrameWidth * 0.667;
	m_FrameHeight = FrameHeight * 0.667;
	m_FrameRect.w = FrameWidth * 0.667;
	m_FrameRect.h = FrameHeight * 0.667;
	m_NumFramesX  = m_pImage->w / m_FrameWidth;
  }

} // Load


// SetColorKey
//
// Aufgabe: Transparente Farbe festlegen
//
void CSprite::SetColorKey (int R, int G, int B)
{
  // Colorkey einstellen
  SDL_SetColorKey (m_pImage, SDL_SRCCOLORKEY, 
                   SDL_MapRGB (m_pImage->format, R, G, B) );

} // SetColorKey


// SetPos
//
// Aufgabe: Position des Sprites festlegen
//
void CSprite::SetPos (float fXPos, float fYPos)
{
  // Rect updaten
  m_Rect.x = static_cast<int>(fXPos);
  m_Rect.y = static_cast<int>(fYPos);

  if(!fullscreen)
  {
	  m_Rect.x *= 0.667;
	  m_Rect.y *= 0.667;
  }

} // SetPos


// Render
//
// Aufgabe: Sprite rendern (ohne Animation)
//
void CSprite::Render (SDL_Surface * screen)
{
	m_pScreen=screen;
	
	SDL_BlitSurface (m_pImage, NULL, m_pScreen, &m_Rect);


} // Render


// Render
//
// Aufgabe: Ausschnitt des Sprites rendern (Animationsphase)
//
void CSprite::Render (SDL_Surface * screen, float fFrameNumber)
{

  m_pScreen=screen;
  // Ausschnitt der aktuellen Animationsphase berechnen
  //

  // Spalte berechnen
  int Column = static_cast<int>(fFrameNumber)%m_NumFramesX;

  // Zeile berechnen
  int Row = static_cast<int>(fFrameNumber)/m_NumFramesX;

  // Rect berechnen
  m_FrameRect.x = Column * m_FrameWidth;
  m_FrameRect.y = Row * m_FrameHeight;


	SDL_BlitSurface (m_pImage, &m_FrameRect, m_pScreen, &m_Rect);		


} // Render
